==> zzyj-outputvalcount-impl-3.0.0-20230612.104713-177-sources.jar: com/ejianc/business/worklog/bean/WorkLabelEntity.java <==
package com.ejianc.business.worklog.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工作日志-工作标签
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_work_log_label")
public class WorkLabelEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="work_label_name")
    private String workLabelName; // 标签
    @TableField(value="department_id")
    private Long departmentId; // 部门
    @TableField(value="department_name")
    private String departmentName; // 部门名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="enable")
    private String enable; // 是否启用(0:未启用-1:启用)
    @TableField(value="last_label_id")
    private Long lastLabelId; // 上级节点id
    @TableField(value="last_label_name")
    private String lastLabelName; // 上级节点名称
    @TableField(value="sort_index")
    private Integer sortIndex; // 排序索引
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getWorkLabelName() {
        return workLabelName;
    }

    public void setWorkLabelName(String workLabelName) {
        this.workLabelName = workLabelName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getEnable() {
        return enable;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }
    public Long getLastLabelId() {
        return lastLabelId;
    }

    public void setLastLabelId(Long lastLabelId) {
        this.lastLabelId = lastLabelId;
    }
    public String getLastLabelName() {
        return lastLabelName;
    }

    public void setLastLabelName(String lastLabelName) {
        this.lastLabelName = lastLabelName;
    }
    public Integer getSortIndex() {
        return sortIndex;
    }

    public void setSortIndex(Integer sortIndex) {
        this.sortIndex = sortIndex;
    }
    
}

==> zzyj-outputvalcount-impl-3.0.0-20250801.060716-371-sources.jar: com/ejianc/business/worklog/bean/WorkLabelEntity.java <==
package com.ejianc.business.worklog.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工作日志-工作标签
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_work_log_label")
public class WorkLabelEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="work_label_name")
    private String workLabelName; // 标签
    @TableField(value="department_id")
    private Long departmentId; // 部门
    @TableField(value="department_name")
    private String departmentName; // 部门名称
    @TableField(value="description")
    private String description; // 描述
    @TableField(value="enable")
    private String enable; // 是否启用(0:未启用-1:启用)
    @TableField(value="last_label_id")
    private Long lastLabelId; // 上级节点id
    @TableField(value="last_label_name")
    private String lastLabelName; // 上级节点名称
    @TableField(value="sort_index")
    private Integer sortIndex; // 排序索引
    @TableField(value="employee_id")
    private Long employeeId; // 姓名
    @TableField(value="employee_name")
    private String employeeName; //
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getWorkLabelName() {
        return workLabelName;
    }

    public void setWorkLabelName(String workLabelName) {
        this.workLabelName = workLabelName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getEnable() {
        return enable;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }
    public Long getLastLabelId() {
        return lastLabelId;
    }

    public void setLastLabelId(Long lastLabelId) {
        this.lastLabelId = lastLabelId;
    }
    public String getLastLabelName() {
        return lastLabelName;
    }

    public void setLastLabelName(String lastLabelName) {
        this.lastLabelName = lastLabelName;
    }
    public Integer getSortIndex() {
        return sortIndex;
    }

    public void setSortIndex(Integer sortIndex) {
        this.sortIndex = sortIndex;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
}
